@@ -284,14 +284,14 @@ function Histogram() {
     self.type = "histogram";
 
     this.setup = function() {
-        this.smoothness = 400;
+        this.smoothness = 100;
         this.nbins = 20;
         this.bar_spacing = 1; // pixels
 
         this.settings_menu.append("div").append("span").text("Bins:");
         this.settings_menu.append("input").attr("value", this.nbins).on("input", function() {
             var value = parseInt(this.value);
-            if(value > 1) {
+            if(value > 1 && value < 1000) {
                 self.nbins = value;
             }
         });
@@ -360,13 +360,13 @@ function Histogram() {
         var bars = this.bars.selectAll("rect")
             .data(this.histogram, function(d, i) { return i; });
 
-        var x_min = d3.min(this.map);
+        var bar_width = (self.w - self.padding_left - self.padding) / self.nbins - self.bar_spacing;
 
         bars.enter()
             .append("rect")
             .attr("x", function(d) { return self.xScale(d.x); })
             .attr("y", function(d) { return self.yScale(d.y); })
-            .attr("width", function(d) { return self.xScale(x_min) - 2*self.padding_left + self.xScale(x_min + d.dx) - self.bar_spacing; })
+            .attr("width", bar_width)
             .attr("height", function(d) { return (self.yScale(0) - self.yScale(d.y)); })
             //.attr("class", function(d) { return d.type; })
             //.attr("fill", function(d) { return self.parameter_color(d.type); });
@@ -376,7 +376,7 @@ function Histogram() {
             .duration(this.smoothness)
             .attr("x", function(d) { return self.xScale(d.x); })
             .attr("y", function(d) { return self.yScale(d.y); })
-            .attr("width", function(d) { return self.xScale(x_min) - 2*self.padding_left + self.xScale(x_min + d.dx) - self.bar_spacing; })
+            .attr("width", bar_width)
             .attr("height", function(d) { return (self.yScale(0) - self.yScale(d.y)); });
 
         bars.exit()
